netapp_ontap.models.firmware_dqp API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.firmware_dqp`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class FirmwareDqpSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the FirmwareDqp object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `file_name GET`

    Firmware file name

    Example: qual_devices_v3

  `record_count GET`

    The record_count field of the firmware_dqp.

  `revision GET`

    Firmware revision

    Example: 20200117

  `version GET`

    Firmware version

    Example: 3.18